==> speech-analytic-testing_1.0.0_database.tar.gz: database/mssql/procedures/SaveCognitiveEngineMigrateStatus.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE PROCEDURE [dbo].[SaveCognitiveEngineMigrateStatus]
(
	@VCC	          VARCHAR(50),
	@Model            VARCHAR(50),
	@Key              VARCHAR(100),
	@Status           INT,
	@StatusCode       VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	--ACTUALIZAR EL ESTADO DE MIGRACIÓN
    IF(@Model = '*')
    BEGIN 
          UPDATE [dbo].[NLU] SET [StatusCode] = @StatusCode,[Status] = @Status WHERE [VCC] = @VCC AND [IsSystemApp] = 0 AND [Status] <> 4
          UPDATE I SET I.[StatusCode] = @StatusCode, I.[Status] = @Status FROM [dbo].[Intent] I JOIN [dbo].[NLU] N 
          ON (I.[VCC] = N.[VCC] AND I.[AppId] = N.[AppId])  WHERE I.[VCC] = @VCC AND N.[IsSystemApp] = 0 AND I.[Status] <> 4
          UPDATE [dbo].[Entity] SET [StatusCode] = @StatusCode, [Status] = @Status WHERE [VCC] = @VCC AND [Status] <> 4
          
          UPDATE U SET U.[StatusCode] = @StatusCode, U.[Status] = @Status FROM [dbo].[Utterance] U JOIN [dbo].[NLU] N 
          ON (U.[VCC] = N.[VCC] AND U.[AppId] = N.[AppId]) WHERE U.[VCC] = @VCC AND N.[IsSystemApp] = 0 AND U.[Status] <> 4
    END--END MODEL * 
    ELSE 
    BEGIN --NLU
    	 IF(@Model = 'nlu')
			  BEGIN
			  	-- STATUS 4 SIGNIFICA QUE ESTA CANCELADO POR VARIOS INTENTOS ERRONEOS
				 IF(@Key = '*')
				 UPDATE [dbo].[NLU] SET [StatusCode] = @StatusCode,[Status] = @Status WHERE [VCC] = @VCC AND [IsSystemApp] = 0 AND [Status] <> 4
				 ELSE
				 BEGIN 
				  IF(@Key = 'AVAILABLE')
				    --ACTUALIZA A DISPONIBLE TODOS LOS QUE MIGRARON
				    UPDATE [dbo].[NLU] SET [StatusCode] = @StatusCode,[Status] = @Status  WHERE [VCC] = @VCC AND [Status] = 8 AND [IsSystemApp] = 0
				  ELSE
				    UPDATE [dbo].[NLU] SET [StatusCode] = @StatusCode,[Status] = @Status  WHERE [VCC] = @VCC AND [Name] = @key AND [IsSystemApp] = 0
				 END
				 
			  END
		  ELSE 
		   BEGIN --INTENT
		   
			  IF(@Model = 'intent')
			    BEGIN 
			    
			     IF(@Key = '*')
				  UPDATE I SET I.[StatusCode] = @StatusCode, I.[Status] = @Status FROM [dbo].[Intent] I JOIN [dbo].[NLU] N 
                  ON (I.[VCC] = N.[VCC] AND I.[AppId] = N.[AppId])  WHERE I.[VCC] = @VCC AND N.[IsSystemApp] = 0 AND I.[Status] <> 4
				 ELSE
				 UPDATE [dbo].[Intent] SET [StatusCode] = @StatusCode, [Status] = @Status  WHERE [VCC] = @VCC AND [IntentId] = @key 
				 
			     END
			   ELSE
			     BEGIN --ENTITY
			       
				    IF(@Model = 'entity')
				    BEGIN 
				    
					     IF(@Key = '*')
						 UPDATE [dbo].[Entity] SET [StatusCode] = @StatusCode, [Status] = @Status WHERE [VCC] = @VCC AND [Status] <> 4
						 ELSE
						 UPDATE [dbo].[Entity] SET [StatusCode] = @StatusCode, [Status] = @Status  WHERE [VCC] = @VCC AND [ID] = @key 
						 
			        END--END ENTITY
			        ELSE 
                        BEGIN --UTTERANCE
	                        IF(@Model = 'utterance')
	                        BEGIN
	                         IF(@Key = '*')
							  UPDATE U SET U.[StatusCode] = @StatusCode, U.[Status] = @Status FROM [dbo].[Utterance] U JOIN [dbo].[NLU] N 
							  ON (U.[VCC] = N.[VCC] AND U.[AppId] = N.[AppId]) WHERE U.[VCC] = @VCC AND N.[IsSystemApp] = 0 AND U.[Status] <> 4
							 ELSE
							 UPDATE [dbo].[Utterance] SET [StatusCode] = @StatusCode, [Status] = @Status  WHERE [VCC] = @VCC AND [Id] = @key 
	                       
	                         END 
                      
						 
	
			             END--UTTERANCE
			       
			         
			    END--ENTITY
			    
		  
		  END -- INTENT
    END--NLU

	SELECT 1 AS result

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/SaveCognitiveEngineMigrateStatus.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE PROCEDURE [dbo].[SaveCognitiveEngineMigrateStatus]
(
	@VCC	          VARCHAR(50),
	@Model            VARCHAR(50),
	@Key              VARCHAR(100),
	@Status           INT,
	@StatusCode       VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	--ACTUALIZAR EL ESTADO DE MIGRACION
    IF(@Model = '*')
    BEGIN 
          UPDATE [dbo].[NLU] SET [StatusCode] = @StatusCode,[Status] = @Status WHERE [VCC] = @VCC AND [IsSystemApp] = 0 AND [Status] <> 4
          UPDATE I SET I.[StatusCode] = @StatusCode, I.[Status] = @Status FROM [dbo].[Intent] I JOIN [dbo].[NLU] N 
          ON (I.[VCC] = N.[VCC] AND I.[AppId] = N.[AppId])  WHERE I.[VCC] = @VCC AND N.[IsSystemApp] = 0 AND I.[Status] <> 4
          UPDATE [dbo].[Entity] SET [StatusCode] = @StatusCode, [Status] = @Status WHERE [VCC] = @VCC AND [Status] <> 4
          
          UPDATE U SET U.[StatusCode] = @StatusCode, U.[Status] = @Status FROM [dbo].[Utterance] U JOIN [dbo].[NLU] N 
          ON (U.[VCC] = N.[VCC] AND U.[AppId] = N.[AppId]) WHERE U.[VCC] = @VCC AND N.[IsSystemApp] = 0 AND U.[Status] <> 4
    END--END MODEL * 
    ELSE 
    BEGIN --NLU
    	 IF(@Model = 'nlu')
			  BEGIN
			  	-- STATUS 4 SIGNIFICA QUE ESTA CANCELADO POR VARIOS INTENTOS ERRONEOS
				 IF(@Key = '*')
				 UPDATE [dbo].[NLU] SET [StatusCode] = @StatusCode,[Status] = @Status WHERE [VCC] = @VCC AND [IsSystemApp] = 0 AND [Status] <> 4
				 ELSE
				 BEGIN 
				  IF(@Key = 'AVAILABLE')
				    --ACTUALIZA A DISPONIBLE TODOS LOS QUE MIGRARON
				    UPDATE [dbo].[NLU] SET [StatusCode] = @StatusCode,[Status] = @Status  WHERE [VCC] = @VCC AND [Status] = 8 AND [IsSystemApp] = 0
				  ELSE
				    UPDATE [dbo].[NLU] SET [StatusCode] = @StatusCode,[Status] = @Status  WHERE [VCC] = @VCC AND [Name] = @key AND [IsSystemApp] = 0
				 END
				 
			  END
		  ELSE 
		   BEGIN --INTENT
		   
			  IF(@Model = 'intent')
			    BEGIN 
			    
			     IF(@Key = '*')
				  UPDATE I SET I.[StatusCode] = @StatusCode, I.[Status] = @Status FROM [dbo].[Intent] I JOIN [dbo].[NLU] N 
                  ON (I.[VCC] = N.[VCC] AND I.[AppId] = N.[AppId])  WHERE I.[VCC] = @VCC AND N.[IsSystemApp] = 0 AND I.[Status] <> 4
				 ELSE
				 UPDATE [dbo].[Intent] SET [StatusCode] = @StatusCode, [Status] = @Status  WHERE [VCC] = @VCC AND [IntentId] = @key 
				 
			     END
			   ELSE
			     BEGIN --ENTITY
			       
				    IF(@Model = 'entity')
				    BEGIN 
				    
					     IF(@Key = '*')
						 UPDATE [dbo].[Entity] SET [StatusCode] = @StatusCode, [Status] = @Status WHERE [VCC] = @VCC AND [Status] <> 4
						 ELSE
						 UPDATE [dbo].[Entity] SET [StatusCode] = @StatusCode, [Status] = @Status  WHERE [VCC] = @VCC AND [ID] = @key 
						 
			        END--END ENTITY
			        ELSE 
                        BEGIN --UTTERANCE
	                        IF(@Model = 'utterance')
	                        BEGIN
	                         IF(@Key = '*')
							  UPDATE U SET U.[StatusCode] = @StatusCode, U.[Status] = @Status FROM [dbo].[Utterance] U JOIN [dbo].[NLU] N 
							  ON (U.[VCC] = N.[VCC] AND U.[AppId] = N.[AppId]) WHERE U.[VCC] = @VCC AND N.[IsSystemApp] = 0 AND U.[Status] <> 4
							 ELSE
							 UPDATE [dbo].[Utterance] SET [StatusCode] = @StatusCode, [Status] = @Status  WHERE [VCC] = @VCC AND [Id] = @key 
	                       
	                         END 
                      
						 
	
			             END--UTTERANCE
			       
			         
			    END--ENTITY
			    
		  
		  END -- INTENT
    END--NLU

	SELECT 1 AS result

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
